<?php
/**
 * Dribble Social media Class file get all social feed
 *
 * @version 1.0
 * @package WP Social Stream Designer PRO
 */

/**
 * Get dribbble stream data
 *
 * @package    Social Stream Designer
 * @subpackage Social Stream Designer/admin/assets/feeds
 * @author     Solwin Infotech <support@solwininfotech.com>
 */
class SSDAdmindribbbleFeeds {
	/**
	 * Table name
	 *
	 * @var string
	 */
	public $feed_posts_table = '';
	/**
	 * Feed object
	 *
	 * @var string
	 */
	public $feeds_object = '';
	/**
	 * Feed details
	 *
	 * @var string
	 */
	public $feed_detail = '';
	/**
	 * Feed id
	 *
	 * @var int
	 */
	public $feed_id = '';
	/**
	 * Next Feed URL
	 *
	 * @var int
	 */
	public $next_url = 1;
	/**
	 * Post Feeds
	 *
	 * @var array
	 */
	public $post_feeds = array();
	/**
	 * Count Feed limit
	 *
	 * @var int
	 */
	public $ssd_feed_limit_count = '0';
	/**
	 * Initial Setup
	 *
	 * @since  1.0.0
	 * @return void
	 */
	public function init() {
		global $wpdb;
		$this->feed_posts_table = $wpdb->prefix . 'ssd_feed_posts';
		if ( isset( $_POST['feed_stream_nonce'] ) ) {
			if ( isset( $_POST['feed_stream_nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['feed_stream_nonce'] ) ), 'social-stream-designer_meta_box_nonce' ) ) {
				if ( isset( $_REQUEST['action'] ) && 'edit' === $_REQUEST['action'] && isset( $_REQUEST['id'] ) && '' != $_REQUEST['id'] ) {
					$this->feed_id = sanitize_text_field( wp_unslash( $_REQUEST['id'] ) );
				}
			}
		}
		$feed_detail       = $this->ssd_get_feed_detail();
		$this->feed_detail = $feed_detail;
	}
	/**
	 * Get feed type from feed id.
	 *
	 * @since  1.0.0
	 * @return array
	 */
	public function ssd_get_feed_detail() {
		global $wpdb;
		$feed_id      = $this->feed_id;
		$result_feeds = $wpdb->get_row( $wpdb->prepare( "select * from $wpdb->prefix" . 'ssd_feeds where id = %d', $feed_id ) );
		if ( $result_feeds ) {
			$feeds_settings  = $result_feeds->feeds_settings;
			$feeds_settings  = maybe_unserialize( $feeds_settings );
			$this->feed_type = $feeds_settings['feed'];
			return $feeds_settings;
		} else {
			return '';
		}
	}
	/**
	 * Get Dribble Social Feeds.
	 *
	 * @since  1.0.0
	 * @return string
	 */
	public function ssd_get_dribbble_stream_from_feed() {
		$feed_detail = $this->feed_detail;
		$feed_limit  = $feed_detail['feed_limit'];
		if ( $feed_limit < 100 ) {
			$count = $feed_limit;
		} else {
			$count = 100;
		}
		/* Get api settings. */
		$dribbble_stream = get_option( 'dribbble_stream' );
		$access_token    = $dribbble_stream['dribbble_access_token'];
		if ( '' === $access_token ) {
			$message = esc_html__( 'Authentication Missing. Please Check Authentication Setting', 'social-stream-designer' );
			return new WP_Error( 'ssd-feeds-errors', $message );
		}
		/* Get User Details */
		$user_url         = 'https://api.dribbble.com/v2/user/?access_token=' . $access_token;
		$get_user         = Social_Stream_Main::ssd_get_data_from_remote_url( $user_url );
		$get_user_details = json_decode( $get_user );
		if ( isset( $get_user_details->message ) ) {
			if ( 'Bad credentials.' === $get_user_details->message ) {
				$message = $get_user_details->message . ' ' . esc_html__( 'Please check your access token.', 'social-stream-designer' );
				return new WP_Error( 'ssd-feeds-errors', $message );
			}
		}
		/* Get User shots details */
		$url       = 'https://api.dribbble.com/v2/user/shots/?per_page=' . $count . '&page=' . $this->next_url . '&access_token=' . $access_token;
		$get_feed  = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
		$get_feeds = json_decode( $get_feed );
		/* Check pagination */
		if ( count( $get_feeds ) >= 1 ) {
			$check_pagination = 'yes';
		} else {
			$check_pagination = 'no';
		}
		$get_php_error = Social_Stream_Main::ssd_get_last_error();
		if ( $get_php_error ) {
			$message = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again', 'social-stream-designer' );
			return new WP_Error( 'ssd-feeds-errors', $message );
		}
		if ( ! empty( $get_feeds ) ) {
			foreach ( $get_feeds as $item ) {
				if ( null === $item->description ) {
					$description = '';
				} else {
					$description = $item->description;
				}
				$created_date                       = $item->published_at;
				$feeds['feed_id']                   = $this->feed_id;
				$feeds['post_comment_id']       	= $item->id;
				$feeds['unique_id']                 = $item->id;
				$feeds['feed_type']                 = 'dribbble';
				$feeds['post_title']                = $item->title;
				$feeds['post_description']          = $item->description;
				$feeds['post_date']                 = $created_date;
				$feeds['post_link']                 = $item->html_url;
				$feeds['post_language']             = '';
				$feeds['post_user_name']            = $get_user_details->name;
				$feeds['post_user_screen_name']     = $get_user_details->name;
				$feeds['post_user_location']        = '';
				$feeds['post_user_description']     = $get_user_details->bio;
				$feeds['post_user_link']            = $get_user_details->html_url;
				$feeds['post_user_image']           = $get_user_details->avatar_url;
				$feeds['post_user_followers_count'] = '';
				$feeds['post_user_friends_count']   = '';
				$feeds['post_retweet_count']        = '';
				$feeds['post_favorite_count']       = '';
				$feeds['post_comment_count']        = '';
				$feeds['post_plays_count']          = '0';
				$feeds['post_likes_count']          = '';
				$feeds['post_dislikes_count']       = '0';
				$feeds['reply_to_link']             = $item->html_url;
				$feeds['retweet_link']              = '';
				$feeds['favourite_link']            = '';
				$feeds['like_link']                 = $item->html_url;
				$feeds['play_link']                 = '';
				$feeds['type_in']                   = 'image';
				$feeds['post_image']                = $item->images->normal;
				$feeds['post_video']                = '';
				$this->ssd_feed_limit_count         = $this->ssd_feed_limit_count + 1;
				if ( $this->ssd_feed_limit_count <= $feed_limit ) {
					$this->post_feeds[] = $feeds;
				}
			}
		}
		if ( 'yes' === $check_pagination ) {
			if ( $this->ssd_feed_limit_count <= $feed_limit ) {
				$this->next_url = 1 + $this->next_url;
				$this->ssd_get_dribbble_stream_from_feed();
			}
		}
	}
}
