<?php
/**
 * Soundcloud Social media class file get all social feed
 *
 * @version 1.0
 * @package WP Social Stream Designer PRO
 */

/**
 * Get Soundcloud stream data
 *
 * @package    Social Stream Designer
 * @subpackage Social Stream Designer/admin/assets/feeds
 * @author     Solwin Infotech <support@solwininfotech.com>
 */
class SSDAdminsoundcloudFeeds {
	/**
	 * Table name
	 *
	 * @var string
	 */
	public $feed_posts_table = '';

	/**
	 * Feed Object
	 *
	 * @var string
	 */
	public $feeds_object = '';
	/**
	 * Feed Details
	 *
	 * @var string
	 */
	public $feed_detail = '';
	/**
	 * Feed ID
	 *
	 * @var int
	 */
	public $feed_id = '';
	/**
	 * Next URL
	 *
	 * @var int
	 */
	public $next_url = 1;
	/**
	 * Post Feeds
	 *
	 * @var array
	 */
	public $post_feeds = array();
	/**
	 * Count Feed limit
	 *
	 * @var int
	 */
	public $ssd_feed_limit_count = '0';
	/**
	 * Initial Setup
	 *
	 * @since  1.0.0
	 * @return void
	 */
	public function init() {
		global $wpdb;
		$this->feed_posts_table = $wpdb->prefix . 'ssd_feed_posts';
		if ( isset( $_POST['feed_stream_nonce'] ) ) {
			if ( isset( $_POST['feed_stream_nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['feed_stream_nonce'] ) ), 'social-stream-designer_meta_box_nonce' ) ) {
				if ( isset( $_REQUEST['action'] ) && 'edit' === $_REQUEST['action'] && isset( $_REQUEST['id'] ) && '' != $_REQUEST['id'] ) {
					$this->feed_id = sanitize_text_field( wp_unslash( $_REQUEST['id'] ) );
				}
			}
		}
		$feed_detail       = $this->ssd_get_feed_detail();
		$this->feed_detail = $feed_detail;
	}
	/**
	 * Get feed type from feed id.
	 *
	 * @since  1.0.0
	 * @return array
	 */
	public function ssd_get_feed_detail() {
		global $wpdb;
		$feed_id      = $this->feed_id;
		$result_feeds = $wpdb->get_row( $wpdb->prepare( "select * from $wpdb->prefix" . 'ssd_feeds where id = %d', $feed_id ) );
		if ( $result_feeds ) {
			$feeds_settings  = $result_feeds->feeds_settings;
			$feeds_settings  = maybe_unserialize( $feeds_settings );
			$this->feed_type = $feeds_settings['feed'];
			return $feeds_settings;
		} else {
			return '';
		}
	}
	/**
	 * Get Playlist URi.
	 *
	 * @param string $user_name soundcloud account user name.
	 * @param string $playlist_name playlist name.
	 * @return string
	 */
	public function ssd_get_playlist_uri( $user_name, $playlist_name ) {
		$soundcloud_stream = get_option( 'soundcloud_stream' );
		$access_token      = $soundcloud_stream['soundcloud_access_token'];
		$url               = 'https://api.soundcloud.com/users/' . $user_name . '/playlists.json?client_id=' . $access_token;
		$data              = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
		$data              = json_decode( $data );
		if ( ! $data ) {
			return false;
		}
		foreach ( $data as $playlist ) {
			if ( isset( $playlist->permalink ) && $playlist_name === $playlist->permalink ) {
				return $playlist->uri;
			}
		}
	}
	/**
	 * Get all sound cloud feeds
	 *
	 * @since  1.0.0
	 * @return string
	 */
	public function ssd_get_soundcloud_stream_from_feed() {
		$tracks                        = array();
		$playlists                     = array();
		$feed_detail                   = $this->feed_detail;
		$feed_limit                    = $feed_detail['feed_limit'];
		$user_name                     = $feed_detail['feed_type_soundcloud_username'];
		$feed_type_soundcloud_playlist = $feed_detail['feed_type_soundcloud_playlist'];
		if ( $feed_limit <= 100 ) {
			$count = $feed_limit;
		} else {
			$count = 100;
		}
		$soundcloud_stream = get_option( 'soundcloud_stream' );
		$access_token      = $soundcloud_stream['soundcloud_access_token'];
		if ( '' == $access_token ) {
			$message = esc_html__( 'Authentication Missing. Please Check Authentication Setting', 'social-stream-designer' );
			return new WP_Error( 'ssd-feeds-errors', $message );
		}
		$url            = 'http://api.soundcloud.com/resolve.json?url=http://soundcloud.com/' . $user_name . '&client_id=' . $access_token;
		$user_json      = Social_Stream_Main::ssd_get_data_from_remote_url( $url );
		$user           = json_decode( $user_json );
		
		$user_id        = $user->id;
		$soundcloud_url = 'http://api.soundcloud.com/users/' . $user_id . '/playlists.json?client_id=' . $access_token;
		$tracks_json    = Social_Stream_Main::ssd_get_data_from_remote_url( $soundcloud_url );
		$tracks         = json_decode( $tracks_json );
		
		$playlist_uri   = $this->ssd_get_playlist_uri( $user_name, $feed_type_soundcloud_playlist );
		
		if ( isset( $tracks ) && ! empty( $tracks ) ) {
			foreach ( $tracks as $item ) {
				$tracks_list = $item->tracks;
				if ( $item->permalink === $feed_type_soundcloud_playlist ) {
					foreach ( $tracks_list as $playlists ) {
						if ( null === $playlists->description ) {
							$description = '';
						} else {
							$description = $playlists->description;
						}
						$profile_img = $playlists->user->avatar_url;
						if ( ! empty( $playlists->video_url ) ) {
							$feeds['type_in']    = 'video';
							$feeds['post_image'] = $playlists->artwork_url;
							$feeds['post_video'] = $playlists->video_url;
						} else {
							$feeds['type_in']    = 'image';
							$feeds['post_image'] = $playlists->artwork_url;
							$feeds['post_video'] = '';
						}
						$created_date                       = strtotime( $playlists->created_at );
						$feeds['feed_id']                   = $this->feed_id;
						$feeds['unique_id']                 = $playlists->id;
						$feeds['post_comment_id']       	= $playlists->id;
						$feeds['feed_type']                 = 'soundcloud';
						$feeds['post_title']                = $playlists->title;
						$feeds['post_description']          = $description;
						$feeds['post_date']                 = gmdate( 'Y-m-d H:i:s', $created_date );
						$feeds['post_link']                 = $playlists->permalink_url;
						$feeds['post_language']             = '';
						$feeds['post_user_name']            = $playlists->user->username;
						$feeds['post_user_screen_name']     = $playlists->user->username;
						$feeds['post_user_location']        = '';
						$feeds['post_user_description']     = '';
						$feeds['post_user_link']            = $playlists->user->permalink_url;
						$feeds['post_user_image']           = $profile_img;
						$feeds['post_user_followers_count'] = '';
						$feeds['post_user_friends_count']   = '';
						$feeds['post_retweet_count']        = '';
						$feeds['post_favorite_count']       = $playlists->favoritings_count;
						$feeds['post_comment_count']        = $playlists->comment_count;
						$feeds['post_plays_count']          = $playlists->playback_count;
						$feeds['post_likes_count']          = $playlists->favoritings_count;
						$feeds['post_dislikes_count']       = '0';
						$feeds['reply_to_link']             = $playlists->permalink_url;
						$feeds['retweet_link']              = '';
						$feeds['favourite_link']            = $playlists->permalink_url;
						$feeds['like_link']                 = $playlists->permalink_url;
						$feeds['play_link']                 = $playlists->permalink_url;
						$this->ssd_feed_limit_count         = $this->ssd_feed_limit_count + 1;
						if ( $this->ssd_feed_limit_count <= $feed_limit ) {
							$this->post_feeds[] = $feeds;
						}
					}
				}
			}
		}
	}
}
