<?php
/**
 * Class file for all actions of stream
 *
 * @version 1.0
 * @package WP Social Stream Designer PRO
 */

/**
 * Class for all common methods of socail stream.
 */
class Social_Stream_Main {
	/**
	 * Class Construct.
	 */
	public function __construct() {
		add_action( 'admin_footer', array( $this, 'ssd_loader_for_feeds' ) );
		add_action( 'wp_ajax_ssd_grid_height', array( $this, 'ssd_grid_height' ), 10 );
		add_action( 'wp_ajax_nopriv_ssd_grid_height', array( $this, 'ssd_grid_height' ), 10 );
		add_action( 'wp_ajax_ssd_approve_feed', array( $this, 'ssd_approve_feed' ), 10 );
		add_action( 'admin_notices', array( $this, 'ssd_no_feeds_available_notice' ) );
		add_action( 'wp_ajax_ssd_update_drag_drop_builder', array( $this, 'ssd_update_drag_drop_builder' ) );
	}
	/**
	 * Create link for facebook story
	 *
	 * @param string $text text to put.
	 * @param string $class class to put in a tag.
	 * @param string $target target of link.
	 * @return html
	 */
	public static function ssd_make_links( $text, $class = '', $target = '_blank' ) {
		return preg_replace( '!((http\:\/\/|ftp\:\/\/|https\:\/\/)|www\.)([-a-zA-Zа-яА-Я0-9\~\!\@\#\$\%\^\&\*\(\)_\-\=\+\\\/\?\.\:\;\'\,]*)?!ism', '<a class="' . $class . '" href="//$3" target="' . $target . '">$1$3</a>', $text );
	}
	/**
	 * Get data from table by ID
	 *
	 * @param int $id id.
	 * @return array table row
	 */
	public function ssd_get_table_row( $id ) {
		global $wpdb;
		return $wpdb->get_row( $wpdb->prepare( "SELECT * FROM $wpdb->prefix" . 'ssd_shortcodes WHERE ID = %d', $id ) );
	}
	/**
	 * Set social stream options value
	 *
	 * @return array $options
	 */
	public static function ssd_get_social_stream_options() {
		$options           = array();
		$twitter_stream    = get_option( 'twitter_stream' );
		$dribbble_stream   = get_option( 'dribbble_stream' );
		$facebook_stream   = get_option( 'facebook_stream' );
		$foursquare_stream = get_option( 'foursquare_stream' );
		$instagram_stream  = get_option( 'instagram_stream' );
		$pinterest_stream  = get_option( 'pinterest_stream' );
		$soundcloud_stream = get_option( 'soundcloud_stream' );
		$tumblr_stream     = get_option( 'tumblr_stream' );
		$vimeo_stream      = get_option( 'vimeo_stream' );
		$youtube_stream    = get_option( 'youtube_stream' );
		$flickr_stream     = get_option( 'flickr_stream' );
		if ( ! empty( $twitter_stream ) ) {
			$options['twitter-stream'] = 'Twitter';
		}
		if ( ! empty( $facebook_stream ) ) {
			$options['facebook-stream'] = 'Facebook';
		}
		if ( ! empty( $youtube_stream ) ) {
			$options['youtube-stream'] = 'YouTube';
		}
		if ( ! empty( $vimeo_stream ) ) {
			$options['vimeo-stream'] = 'Vimeo';
		}
		$options['pinterest-stream'] = 'Pinterest';
		if ( ! empty( $flickr_stream ) ) {
			$options['flickr-stream'] = 'Flickr';
		}
		if ( ! empty( $instagram_stream ) ) {
			$options['instagram-stream'] = 'Instagram';
		}
		if ( ! empty( $tumblr_stream ) ) {
			$options['tumblr-stream'] = 'Tumblr';
		}
		if ( ! empty( $dribbble_stream ) ) {
			$options['dribbble-stream'] = 'Dribbble';
		}
		$options['wordpress-stream'] = 'WordPress';
		$options['rss-stream']       = 'RSS';
		if ( ! empty( $foursquare_stream ) ) {
			$options['foursquare-stream'] = 'Foursquare';
		}
		if ( ! empty( $soundcloud_stream ) ) {
			$options['soundcloud-stream'] = 'SoundCloud';
		}
				$options['tiktok-stream'] = 'Tiktok';
		return $options;
	}
	/**
	 * Converts a number into a short version, eg: 1000 -> 1k
	 *
	 * @param int $number number.
	 * @return string $number number
	 */
	public static function ssd_formatwithsuffix( $number ) {
		$suffixes     = array( '', 'k', 'm', 'g', 't' );
		$suffix_index = 0;
		$suffixes_ct  = count( $suffixes );
		while ( abs( $number ) >= 1000 && $suffix_index < $suffixes_ct ) {
			$suffix_index++;
			$number /= 1000;
		}
		return ( $number > 0 ? floor( $number * 10 ) / 10 : ceil( $number * 10 ) / 10 ) . $suffixes[ $suffix_index ];
	}
	/**
	 * Set Feed Pagination
	 *
	 * @param array $social_stream_settings social data array.
	 * @param int   $total_pages_for_pagination Total pages.
	 * @param int   $cur_page Current page.
	 * @param int   $cur_page_for_pagination Current page.
	 * @param int   $pages_to_display_for_pagination pages to display for pagination.
	 * @return Pagination
	 */
	public static function ssd_get_feed_pagination( $social_stream_settings, $total_pages_for_pagination, $cur_page, $cur_page_for_pagination = 1, $pages_to_display_for_pagination = 7 ) {
		ob_start();
		$ssd_pagination_layout = '';
		$ssd_pagination_type   = ( isset( $social_stream_settings['ssd_pagination_type'] ) && '' !== $social_stream_settings['ssd_pagination_type'] ) ? $social_stream_settings['ssd_pagination_type'] : 'no_pagination';
		if ( 'paged' === $ssd_pagination_type ) {
			$ssd_pagination_layout = ( isset( $social_stream_settings['ssd_pagination_layout'] ) && '' !== $social_stream_settings['ssd_pagination_layout'] ) ? $social_stream_settings['ssd_pagination_layout'] : 'template-1';
		}
		if ( 'load_more_btn' === $ssd_pagination_type ) {
			$ssd_pagination_layout = ( isset( $social_stream_settings['ssd_load_more_layout'] ) && '' !== $social_stream_settings['ssd_load_more_layout'] ) ? $social_stream_settings['ssd_load_more_layout'] : 'template-1';
		}
		?>
		<div class="ssd-center ssd-row-padding ssd-block ssd-padding-32">
			<div class="ssd-pgn-bar <?php echo esc_attr( $ssd_pagination_layout ); ?>">
				<?php
				$pages_to_display_for_pagination = (int) $pages_to_display_for_pagination;
				if ( $pages_to_display_for_pagination > 0 ) {
					for ( $i = 1; $i <= $pages_to_display_for_pagination; $i++ ) {
						$page_id  = $pages_to_display_for_pagination * $cur_page_for_pagination + $i;
						$ex_class = '';
						if ( $cur_page == $page_id ) {
							$ex_class .= 'ssd-page-active';
						}
						$previous_page_id = $cur_page - 1;
						$next_page_id     = $cur_page + 1;
						if ( $cur_page_for_pagination > 0 && 1 == $i ) {
							$fisrt_previous_page_id = $pages_to_display_for_pagination * ( $cur_page_for_pagination - 1 ) + 1;
							?>
							<a class="ssd-bar-item ssd-button ssd-hover-black ssd-border ssd-margin-right-small" href="<?php echo esc_url( add_query_arg( 'cur_page', $fisrt_previous_page_id ) ); ?>"><<</a>
							<?php
						}
						if ( $previous_page_id > 0 && 1 == $i ) {
							?>
							<a class="ssd-bar-item ssd-button ssd-hover-black ssd-border ssd-margin-right-small" href="<?php echo esc_url( add_query_arg( 'cur_page', $previous_page_id ) ); ?>"><</a>
							<?php
						}
						if ( $page_id <= $total_pages_for_pagination ) {
							$cur_page2 = (int) $cur_page + 1;
							if ( $page_id == $cur_page2 ) {
								$ex_class .= 'next';
							}
							?>
							<a class="ssd-bar-item ssd-button ssd-hover-black ssd-border ssd-margin-right-small <?php echo esc_attr( $ex_class ); ?>" href="<?php echo esc_url( add_query_arg( 'cur_page', $page_id ) ); ?>" ><?php echo esc_attr( $page_id ); ?></a>
							<?php
						}
						if ( $next_page_id <= $total_pages_for_pagination && $i == $pages_to_display_for_pagination ) {
							?>
							<a class="ssd-bar-item ssd-button ssd-hover-black ssd-border ssd-margin-right-small" href="<?php echo esc_url( add_query_arg( 'cur_page', $next_page_id ) ); ?>">></a>
							<?php
						}
						$first_last_page_id = $pages_to_display_for_pagination * ( $cur_page_for_pagination + 1 ) + 1;
						if ( $first_last_page_id < $total_pages_for_pagination && $i == $pages_to_display_for_pagination ) {
							?>
							<a class="ssd-bar-item ssd-button ssd-hover-black ssd-border ssd-margin-right-small"  href="<?php echo esc_url( add_query_arg( 'cur_page', $first_last_page_id ) ); ?>">>></a>
							<?php
						}
					}
				}
				?>
			</div>
		</div>
		<?php
		$pagination_html = ob_get_clean();
		return $pagination_html;
	}
	/**
	 * Display share labels in layout
	 *
	 * @param string $social_cover_class cover class.
	 * @param string $social_stream_settings cover class.
	 * @param string $feed_type cover food type.
	 * @return void
	 */
	public static function ssd_social_share_labels( $social_cover_class, $social_stream_settings, $feed_type ) {
		$ssd_social_share_type = isset( $social_stream_settings['ssd_social_share_type'] ) ? $social_stream_settings['ssd_social_share_type'] : 'text';
		$ssd_display_image     = isset( $social_stream_settings['ssd_display_image'] ) ? $social_stream_settings['ssd_display_image'] : '';
		$ssd_icon_image_layout = isset( $social_stream_settings['ssd_image_layout'] ) ? $social_stream_settings['ssd_image_layout'] : '';
		if ( 'facebook' === $feed_type ) {
			$icon = 'fab fa-facebook-f';
		} elseif ( 'twitter' === $feed_type ) {
			$icon = 'fab fa-twitter';
		} elseif ( 'instagram' === $feed_type ) {
			$icon = 'fab fa-instagram';
		} elseif ( 'vimeo' === $feed_type ) {
			$icon = 'fab fa-vimeo-v';
		} elseif ( 'youtube' === $feed_type ) {
			$icon = 'fab fa-youtube';
		} elseif ( 'pinterest' === $feed_type ) {
			$icon = 'fab fa-pinterest';
		} elseif ( 'flickr' === $feed_type ) {
			$icon = 'fab fa-flickr';
		} elseif ( 'dribbble' === $feed_type ) {
			$icon = 'fab fa-dribbble';
		} elseif ( 'WordPress' === $feed_type || 'wordpress' === $feed_type ) {
			$icon = 'fab fa-wordpress';
		} elseif ( 'rss' === $feed_type ) {
			$icon = 'fab fa-rss';
		} elseif ( 'foursquare' === $feed_type ) {
			$icon = 'fab fa-foursquare';
		} elseif ( 'tumblr' === $feed_type ) {
			$icon = 'fab fa-tumblr';
		} elseif ( 'soundcloud' === $feed_type ) {
			$icon = 'fab fa-soundcloud';
		} elseif ( 'tiktok' === $feed_type ) {
			$icon = 'fab fa-tiktok';
		}
		?>
		<div class="ssdso-icn <?php echo esc_attr( $social_cover_class ); ?>">
			<?php
			if ( $feed_type ) {
				?>
				<div class="ssd-share-label">
					<?php
					if ( 'icon' === $ssd_social_share_type ) {
						if ( '1' !== $ssd_display_image ) {
							if ( isset( $icon ) ) {
								?>
								<i class="<?php echo esc_attr( $icon ); ?>"></i>
								<?php
							}
						} else {
							?>
							<span class="<?php echo ' ' . esc_attr( $ssd_icon_image_layout ); ?>"></span>
							<?php
						}
					}
					if ( 'icon_text' === $ssd_social_share_type ) {
						if ( isset( $icon ) ) {
							?>
							<i class="<?php echo esc_attr( $icon ); ?>"></i>
							<?php
						}
					}
					if ( 'icon' !== $ssd_social_share_type ) {
						?>
						<span><?php echo esc_html( $feed_type ); ?></span>
						<?php
					}
					?>
				</div>
				<?php
			}
			?>
		</div>
		<?php
	}
	/**
	 * Get Viemo Thumb Image
	 *
	 * @param int    $id video id.
	 * @param string $size image size.
	 * @return string
	 */
	public static function viemo_thumb( $id, $size = 'medium' ) {
		$id = trim( $id );
		if ( '' == $id ) {
			return false;
		}
		$api_data = unserialize( file_get_contents( "http://vimeo.com/api/v2/video/$id.php" ) );
		if ( is_array( $api_data ) && count( $api_data ) > 0 ) {

			$video_info = $api_data[0];
			switch ( $size ) {
				case 'small':
					return $video_info['thumbnail_small'];
					break;
				case 'large':
					return $video_info['thumbnail_large'];
					break;
				case 'medium':
					return $video_info['thumbnail_medium'];
				default:
					break;
			}
		}
		return false;
	}
	/**
	 * Display author data in layout
	 *
	 * @param string $social_cover_class cover class.
	 * @param array  $social_stream_settings social settings array.
	 * @param object $feeds feeds.
	 * @return void
	 */
	public static function ssd_author_data( $social_cover_class, $social_stream_settings, $feeds ) {
		$upload_file  = '';
		$display_file = '';
		$feed_type    = $feeds->feed_type;
		$user_image   = $feeds->post_user_image;
		if ( '' !== $user_image ) {
			$upload_file_path    = WP_CONTENT_DIR . '/uploads/social-stream/';
			$display_file_path   = WP_CONTENT_URL . '/uploads/social-stream/';
			$post_user_image_url = strtok( $user_image, '?' );
			$path_info           = pathinfo( $post_user_image_url );
			$file_extention      = '';
			if ( isset( $path_info['extension'] ) ) {
				$file_extention = $path_info['extension'];
				if ( '' !== $file_extention ) {
					$file_extentions = wp_parse_url( $file_extention );
					if ( is_array( $file_extentions ) ) {
						$file_extention = $file_extentions['path'];
					}
					$file_extention = '.' . $file_extention;
				} else {
					$file_extention = '.jpg';
				}
			} else {
				$file_extention = '.jpg';
			}
			$file_name    = md5( $post_user_image_url );
			$upload_file  = $upload_file_path . $file_name . '_profile' . $file_extention;
			$display_file = $display_file_path . $file_name . '_profile' . $file_extention;
		}
		$user_link        = $feeds->post_user_link;
		$user_name        = $feeds->post_user_name;
		$user_screen_name = $feeds->post_user_screen_name;
		$user_screen_name = ( isset( $user_screen_name ) && '' !== $user_screen_name ) ? '@' . $user_screen_name : '';
		$date_time        = $feeds->post_date;
		$date_time        = human_time_diff( strtotime( $date_time ), current_time( 'timestamp' ) ) . ' ago';
		if ( null == $feeds->post_date || '0000-00-00 00:00:00' == $feeds->post_date ) {
			$date_time = '';
		}

		$ssd_design_layout     = isset( $social_stream_settings['ssd_design_layout'] ) ? $social_stream_settings['ssd_design_layout'] : 'layout-1';
		$ssd_display_sticky    = isset( $social_stream_settings['ssd_display_sticky'] ) ? $social_stream_settings['ssd_display_sticky'] : '1';
		$ssd_display_sticky_on = isset( $social_stream_settings['ssd_display_sticky_on'] ) ? $social_stream_settings['ssd_display_sticky_on'] : 'media';
		$show_view_user_name   = isset( $social_stream_settings['ssd_view_user_name'] ) ? $social_stream_settings['ssd_view_user_name'] : '';
		$show_view_user_name   = (int) $show_view_user_name;
		$show_view_date        = isset( $social_stream_settings['ssd_view_date'] ) ? $social_stream_settings['ssd_view_date'] : '';
		$show_view_date        = (int) $show_view_date;
		$ssd_layout            = isset( $social_stream_settings['ssd_layout'] ) ? $social_stream_settings['ssd_layout'] : '';
		?>
		<div class="ssd-author-detail">
			<div class='ssd-author-image'>
				<?php
				if ( file_exists( $upload_file ) ) {
					?>
					<img src='<?php echo esc_url( $display_file ); ?>' alt="<?php echo esc_attr( $user_name ); ?>"/>
					<?php
				} elseif ( isset( $user_image ) && '' !== $user_image ) {
					?>
					<img src='<?php echo esc_url( $user_image ); ?>' alt="<?php echo esc_attr( $user_name ); ?>"/>
					<?php
				} else {
					?>
					<img src='<?php echo esc_attr( SOCIALSTREAMDESIGNER_URL ) . '/images/author.png'; ?>' alt="<?php echo esc_attr( $user_name ); ?>"/>
					<?php
				}
				?>
			</div>
			<?php
			if ( 'author' === $ssd_display_sticky_on ) {
				self::ssd_social_share_labels( $social_cover_class, $social_stream_settings, $feed_type );
			}
			?>
			<div class="ssd-author-name">
				<div class="author-name-top"><a class="ssd-display-name" target="_blank" href='<?php echo esc_url( $user_link ); ?>'><?php echo esc_attr( $user_name ); ?></a></div>
				<?php if ( 1 == $show_view_user_name || 1 == $show_view_date ) { ?>
					<div class="author-name-bottom">
						<?php
						if ( '' != $user_screen_name && '1' == $show_view_user_name ) {
							?>
							<a class="ssd-user-name" target="_blank"  href='<?php echo esc_url( $user_link ); ?>'><?php echo esc_attr( $user_screen_name ); ?></a>
							<?php
						}
						if ( 'timeline' !== $ssd_layout ) {
							if ( '' != $date_time && '1' == $show_view_date ) {
								?>
									<div class="ssd-posted-date">
										<?php echo ' - ' . esc_attr( $date_time ); ?>
									</div>
									<?php
							}
						}
						?>
					</div>
				<?php } ?>
			</div>
		</div>
		<?php
	}
	/**
	 * Display share counts in layout
	 *
	 * @param array  $social_stream_settings stream settings array.
	 * @param object $feeds feeds.
	 * @return void
	 */
	public static function ssd_social_share_count( $social_stream_settings, $feeds ) {
		global $wpdb;
		$show_follower_count                                = isset( $social_stream_settings['ssd_user_follower_count'] ) ? $social_stream_settings['ssd_user_follower_count'] : '';
		$show_friend_count                                  = isset( $social_stream_settings['ssd_user_friend_count'] ) ? $social_stream_settings['ssd_user_friend_count'] : '';
		$show_retweet_count                                 = isset( $social_stream_settings['ssd_retweet_count'] ) ? $social_stream_settings['ssd_retweet_count'] : '';
		$show_retweet_count                                 = (int) $show_retweet_count;
		$show_reply_count                                   = isset( $social_stream_settings['ssd_reply_link'] ) ? $social_stream_settings['ssd_reply_link'] : '';
		$show_reply_count                                   = (int) $show_reply_count;
		$show_view_count                                    = isset( $social_stream_settings['ssd_view_count'] ) ? $social_stream_settings['ssd_view_count'] : '';
		$show_view_count                                    = (int) $show_view_count;
		$show_favorite_count                                = isset( $social_stream_settings['ssd_favorite_count'] ) ? $social_stream_settings['ssd_favorite_count'] : '';
		$show_favorite_count                                = (int) $show_favorite_count;
		$show_like_count                                    = isset( $social_stream_settings['ssd_like_count'] ) ? $social_stream_settings['ssd_like_count'] : '';
		$show_like_count                                    = (int) $show_like_count;
		$show_pin_count                                     = isset( $social_stream_settings['ssd_pin_count'] ) ? $social_stream_settings['ssd_pin_count'] : '';
		$show_pin_count                                     = (int) $show_pin_count;
		$show_like_link                                     = isset( $social_stream_settings['ssd_like_link'] ) ? $social_stream_settings['ssd_like_link'] : '';
		$show_dislike_count                                 = isset( $social_stream_settings['ssd_dislike_count'] ) ? $social_stream_settings['ssd_dislike_count'] : '';
		$show_dislike_count                                 = (int) $show_dislike_count;
		$show_comment_count                                 = isset( $social_stream_settings['ssd_comment_count'] ) ? $social_stream_settings['ssd_comment_count'] : '';
		$show_comment_count                                 = (int) $show_comment_count;
		$show_comment_link                                  = isset( $social_stream_settings['ssd_comment_link'] ) ? $social_stream_settings['ssd_comment_link'] : '';
		$show_share_with                                    = isset( $social_stream_settings['ssd_display_share_with'] ) ? $social_stream_settings['ssd_display_share_with'] : '';
		$show_share_with                                    = (int) $show_share_with;
										  $show_share_count = isset( $social_stream_settings['ssd_share_count'] ) ? $social_stream_settings['ssd_share_count'] : '';
		$show_share_count                                   = (int) $show_share_count;
		$feed_type            = $feeds->feed_type;
		$user_followers_count = '' !== $feeds->post_user_followers_count ? $feeds->post_user_followers_count : 0;
		$user_friends_count   = '' !== $feeds->post_user_friends_count ? $feeds->post_user_friends_count : 0;
		$comments_count       = '' !== $feeds->post_comment_count ? $feeds->post_comment_count : 0;
		$favorite_count       = '' !== $feeds->post_favorite_count ? $feeds->post_favorite_count : 0;
		$likes_count          = '' !== $feeds->post_likes_count ? $feeds->post_likes_count : 0;
		$dislike_count        = '' !== $feeds->post_dislikes_count ? $feeds->post_dislikes_count : 0;
		$plays_count          = '' !== $feeds->post_plays_count ? $feeds->post_plays_count : 0;
		$retweet_count        = '' !== $feeds->post_retweet_count ? $feeds->post_retweet_count : 0;
		$reply_to_link        = $feeds->reply_to_link;
		$retweet_link         = $feeds->retweet_link;
		$favourite_link       = $feeds->favourite_link;
		$like_link            = $feeds->like_link;
		$plays_link           = $feeds->play_link;
		$post_link            = $feeds->post_link;
		$post_video           = $feeds->post_video;
		// $message_2           	= $feeds->message_2;
		$unique_id            = $feeds->unique_id;
		if( 'facebook' === $feed_type ) {
			$result_feeds                   = $wpdb->get_results( $wpdb->prepare( "select * from $wpdb->prefix" . 'ssd_feeds where id = %d', $feeds->feed_id ) );
			$feed_setting                   = unserialize( $result_feeds[0]->feeds_settings );
			$feed_type_stream = $feed_setting[ 'feed_type_' . $feed_type ];
		}

		if ( 'twitter' === $feed_type ) {
			if ( 1 == $show_retweet_count || 1 == $show_favorite_count || 1 == $show_reply_count ) {
				echo '<div class="ssd-action-row">';
			}
			if ( 1 == $show_reply_count ) {
				?>
				<a target="_blank" title="<?php esc_html_e( 'Reply', 'social-stream-designer' ); ?>" href="<?php echo esc_url( $reply_to_link ); ?>">
					<i class='fas fa-reply'></i>
				</a>
				<?php
			}
			if ( 1 == $show_retweet_count ) {
				?>
				<a target="_blank" title="<?php esc_html_e( 'Retweet', 'social-stream-designer' ); ?>" href="<?php echo esc_url( $retweet_link ); ?>">
					<i class='fas fa-retweet'></i>
					<?php if ( '' !== $retweet_count ) { ?>
					<span class='ssd-counts'><?php echo esc_attr( $retweet_count ); ?></span>
					<?php } ?>
				</a>
				<?php
			}
			if ( 1 == $show_favorite_count ) {
				?>
				<a target="_blank" title="<?php esc_html_e( 'Favorite', 'social-stream-designer' ); ?>" href="<?php echo esc_url( $favourite_link ); ?>">
					<i class='far fa-heart'></i>
					<?php if ( '' !== $favorite_count ) { ?>
					<span class='ssd-counts'><?php echo esc_attr( $favorite_count ); ?></span>
					<?php } ?>
				</a>
				<?php
			}
			if ( 1 == $show_retweet_count || 1 == $show_favorite_count || 1 == $show_reply_count ) {
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
			if ( 1 !== $show_retweet_count && 1 !== $show_favorite_count && 1 !== $show_reply_count && 1 == $show_share_with ) {
				echo '<div class="ssd-action-row">';
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
		} elseif ( 'tiktok' === $feed_type ) {
			if ( 1 == $show_favorite_count || 1 == $show_comment_count || 1 == $show_share_count || 1 == $plays_count ) {
				echo '<div class="ssd-action-row">';
			}
			if ( 1 == $show_favorite_count ) {
				?>
				<a target="_blank" title="<?php esc_html_e( 'Favorite', 'social-stream-designer' ); ?>" href="<?php echo esc_url( $favourite_link ); ?>">
					<i class='fas fa-heart'></i>
				<?php if ( '' !== $favorite_count ) { ?>
					<span class='ssd-counts'><?php echo esc_attr( $favorite_count ); ?></span>
					<?php } ?>
				</a>
				<?php
			}
			if ( 1 == $show_comment_count ) {
				?>
				<a target="_blank" title="<?php esc_html_e( 'Comment', 'social-stream-designer' ); ?>" href="<?php echo esc_url( $reply_to_link ); ?>">
					<i class="fas fa-comment"></i>
															<?php if ( '' != $comments_count ) { ?>
					<span class='ssd-counts'><?php echo esc_attr( $comments_count ); ?></span>
					<?php } ?>
				</a>
						<?php
			}
			if ( 1 == $show_share_count ) {
				?>
				<a target="_blank" title="<?php esc_html_e( 'Share', 'social-stream-designer' ); ?>" href="<?php echo esc_url( $retweet_link ); ?>">
					<i class="fas fa-share"></i>
						<?php if ( '' !== $retweet_count ) { ?>
					<span class='ssd-counts'><?php echo esc_attr( $retweet_count ); ?></span>
					<?php } ?>
				</a>
						<?php
			}
			if ( 1 == $show_view_count ) {
				?>
				<a target="_blank" title="<?php esc_html_e( 'View', 'social-stream-designer' ); ?>" href="<?php echo esc_url( $retweet_link ); ?>">
					<i class="fas fa-play"></i>
					<?php if ( '' !== $plays_count ) { ?>
					<span class='ssd-counts'><?php echo esc_attr( $plays_count ); ?></span>
					<?php } ?>
				</a>
					<?php
			}

			if ( 1 == $show_favorite_count || 1 == $show_comment_count || 1 == $show_share_count ) {
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
			if ( 1 !== $show_favorite_count && 1 !== $show_comment_count && 1 !== $show_share_count && 1 == $show_share_with ) {
				echo '<div class="ssd-action-row">';
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
		} elseif ( 'facebook' === $feed_type ) {
			if( ('all_album' === $feed_type_stream ) ) {
				echo '<div class="ssd-action-row">';
				?><span class="ssd-photo-count"><?php echo $favorite_count.' '; esc_html_e( 'photos', 'social-stream-designer' ); ?><span><?php
				if(1 == $show_share_with){
					self::ssd_display_share_with_icon( $show_share_with, $post_link );
				}
				
				echo '</div>';
			} else {
				if ( ( 1 == $show_comment_count && '' !== $comments_count ) || ( 1 == $show_like_count && '' !== $likes_count ) ) {
					echo '<div class="ssd-action-row">';
				}
				
				if ( 1 == $show_comment_count && '' !== $comments_count ) {
					?>
					<a target="_blank" href="<?php echo esc_url( $post_link ); ?>" title="<?php esc_html_e( 'Comments', 'social-stream-designer' ); ?>" ><i class='fas fa-comments'></i><span class='ssd-counts'><?php echo esc_attr( $comments_count ); ?></span></a>
														<?php
				}
				if ( 1 == $show_like_count && '' !== $likes_count ) {
					?>
					<a target="_blank" href="<?php echo esc_url( $like_link ); ?>" title="<?php esc_html_e( 'Likes', 'social-stream-designer' ); ?>" ><i class='far fa-thumbs-up'></i><span class='ssd-counts'><?php echo esc_attr( $likes_count ); ?></span></a>
														<?php
				}
				if ( ( 1 == $show_comment_count && '' !== $comments_count ) || ( 1 == $show_like_count && '' !== $likes_count ) ) {
					self::ssd_display_share_with_icon( $show_share_with, $post_link );
					echo '</div>';
				}
				if ( 1 !== $show_comment_count && 1 !== $show_like_count && 1 == $show_share_with ) {
					echo '<div class="ssd-action-row">';
					self::ssd_display_share_with_icon( $show_share_with, $post_link );
					echo '</div>';
				}
			}
			
		} elseif ( 'youtube' === $feed_type ) {
			if ( ( 1 == $show_comment_count && '' !== $comments_count ) || ( 1 == $show_like_count && '' !== $likes_count ) || ( 1 == $show_view_count && '' !== $plays_count ) || ( 1 == $show_dislike_count && '' !== $dislike_count ) ) {
				echo '<div class="ssd-action-row">';
			}
			if ( 1 == $show_comment_count && '' !== $comments_count ) {
				?>
					<a target="_blank" href="<?php echo esc_url( $post_link ); ?>" title="<?php esc_html_e( 'Comments', 'social-stream-designer' ); ?>" ><i class='fas fa-comments'></i><span class='ssd-counts'><?php echo esc_html( $comments_count ); ?></span></a>
														<?php
			}
			if ( 1 == $show_like_count && '' !== $likes_count ) {
				?>
					<a target="_blank" href="<?php echo esc_url( $post_link ); ?>" title="<?php esc_html_e( 'Likes', 'social-stream-designer' ); ?>" ><i class='far fa-thumbs-up'></i><span class='ssd-counts'><?php echo esc_html( $likes_count ); ?></span></a>
														<?php
			}
			if ( 1 == $show_dislike_count && '' !== $dislike_count ) {
				?>
					<a target="_blank" href="<?php echo esc_url( $post_link ); ?>" title="<?php esc_html_e( 'Dislikes', 'social-stream-designer' ); ?>" ><i class='far fa-thumbs-down'></i><span class='ssd-counts'><?php echo esc_html( $dislike_count ); ?></span></a>
														<?php
			}
			if ( 1 == $show_view_count && '' !== $plays_count ) {
				?>
					<a target="_blank" href="<?php echo esc_url( $post_link ); ?>" title="<?php esc_html_e( 'Views', 'social-stream-designer' ); ?>" ><i class='far fa-eye'></i><span class='ssd-counts'><?php echo esc_html( $plays_count ); ?></span></a>
														<?php
			}
			if ( ( 1 == $show_comment_count && '' !== $comments_count ) || ( 1 == $show_like_count && '' !== $likes_count ) || ( 1 == $show_view_count && '' !== $plays_count ) || ( 1 == $show_dislike_count && '' !== $dislike_count ) ) {
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
			if ( 1 !== $show_comment_count && 1 !== $show_like_count && 1 !== $show_view_count && 1 !== $show_dislike_count && 1 == $show_share_with ) {
				echo '<div class="ssd-action-row">';
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
		} elseif ( 'vimeo' === $feed_type ) {
					$like_link                        = $post_link;
										$comment_link = $post_link;
			if ( ( 1 == $show_comment_count && '' !== $comments_count ) || ( 1 == $show_like_count && '' !== $likes_count ) || ( 1 == $show_view_count && '' !== $plays_count ) ) {
				echo '<div class="ssd-action-row">';
			}
			if ( 1 == $show_comment_count && '' !== $comments_count ) {
				?>
				<a target="_blank" href="<?php echo esc_url( $like_link ); ?>" title="<?php esc_html_e( 'Comments', 'social-stream-designer' ); ?>" ><i class='fas fa-comments'></i><span class='ssd-counts'><?php echo esc_html( $comments_count ); ?></span></a>
				<?php
			}
			if ( 1 == $show_like_count && '' !== $likes_count ) {
				?>
				<a target="_blank" href="<?php echo esc_url( $comment_link ); ?>" title="<?php esc_html_e( 'Likes', 'social-stream-designer' ); ?>" ><i class='far fa-thumbs-up'></i><span class='ssd-counts'><?php echo esc_html( $likes_count ); ?></span></a>
				<?php
			}
			if ( 1 == $show_view_count && '' !== $plays_count ) {
				?>
				<a target="_blank" href="<?php echo esc_url( $post_link ); ?>" title="<?php esc_html_e( 'Views', 'social-stream-designer' ); ?>" ><i class='far fa-eye'></i><span class='ssd-counts'><?php echo esc_html( $plays_count ); ?></span></a>
				<?php
			}
			if ( ( 1 == $show_comment_count && '' !== $comments_count ) || ( 1 == $show_like_count && '' !== $likes_count ) || ( 1 == $show_view_count && '' !== $plays_count ) ) {
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
			if ( 1 !== $show_comment_count && 1 !== $show_like_count && 1 !== $show_view_count && 1 == $show_share_with ) {
				echo '<div class="ssd-action-row">';
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
		} elseif ( 'pinterest' === $feed_type ) {
			if ( 1 == $show_pin_count ) {
				echo '<div class="ssd-action-row">';
			}
			if ( 1 == $show_pin_count && '' !== $show_pin_count ) {
				?>
				<a target="_blank" target="_blank" href="https://www.pinterest.com/pin/<?php echo esc_attr( $unique_id ); ?>" title="<?php esc_html_e( 'Pins', 'social-stream-designer' ); ?>" ><i class='fas fa-thumbtack'></i><span class='ssd-counts'><?php echo esc_attr( $likes_count ); ?></span></a>
				<?php
			}
			if ( 1 == $show_pin_count ) {
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
			if ( 1 !== $show_pin_count && 1 == $show_share_with ) {
				echo '<div class="ssd-action-row">';
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
		} elseif ( 'flickr' === $feed_type ) {
			$like_link    = $post_link;
			$comment_link = $post_link;
			if ( ( 1 == $show_comment_count && '' !== $comments_count ) || ( 1 == $show_like_count && '' !== $likes_count ) || ( 1 == $show_view_count && '' !== $plays_count ) ) {
				echo '<div class="ssd-action-row">';
			}
			if ( 1 == $show_comment_count && '' !== $comments_count ) {
				?>
				<a target="_blank" href="<?php echo esc_url( $comment_link ); ?>" title="<?php esc_html_e( 'Comments', 'social-stream-designer' ); ?>" ><i class='fas fa-comments'></i><span class='ssd-counts'><?php echo esc_html( $comments_count ); ?></span></a>
				<?php
			}
			if ( 1 == $show_like_count && '' !== $likes_count ) {
				?>
				<a target="_blank" href="<?php echo esc_url( $like_link ); ?>" title="<?php esc_html_e( 'Likes', 'social-stream-designer' ); ?>" ><i class='far fa-thumbs-up'></i><span class='ssd-counts'><?php echo esc_html( $likes_count ); ?></span></a>
				<?php
			}
			if ( 1 == $show_view_count && '' !== $plays_count ) {
				?>
				<a target="_blank" href="<?php echo esc_url( $post_link ); ?>" title="<?php esc_html_e( 'Views', 'social-stream-designer' ); ?>" ><i class='far fa-eye'></i><span class='ssd-counts'><?php echo esc_html( $plays_count ); ?></span></a>
				<?php
			}
			if ( ( 1 == $show_comment_count && '' !== $comments_count ) || ( 1 == $show_like_count && '' !== $likes_count ) || ( 1 == $show_view_count && '' !== $plays_count ) ) {
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
			if ( 1 !== $show_comment_count && 1 !== $show_like_count && 1 !== $show_view_count && 1 == $show_share_with ) {
				echo '<div class="ssd-action-row">';
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
		} elseif ( 'instagram' === $feed_type ) {
			$like_link    = $post_link;
			$comment_link = $post_link;
			if ( 1 == $show_comment_count || 1 == $show_like_count ) {
				echo '<div class="ssd-action-row">';
			}
			if ( 1 == $show_like_count ) {
				?>
				<a target="_blank" title="<?php esc_html_e( 'Likes', 'social-stream-designer' ); ?>" href="<?php echo esc_url( $like_link ); ?>">
					<i class='fas fa-heart'></i>
					<?php if ( 1 == $show_like_count && '' !== $likes_count ) { ?>
						<span class='ssd-counts'><?php echo esc_html( $likes_count ); ?></span>
						<?php
					}
					?>
				</a>
				<?php
			}
			if ( 1 == $show_comment_count ) {
				?>
				<a target="_blank" href="<?php echo esc_url( $comment_link ); ?>" title="<?php esc_html_e( 'Comments', 'social-stream-designer' ); ?>" >
					<i class='fas fa-comments'></i>
					<?php if ( 1 == $show_comment_count && '' !== $comments_count ) { ?>
						<span class='ssd-counts'><?php echo esc_html( $comments_count ); ?></span>
						<?php
					}
					?>
				</a>
				<?php
			}
			if ( 1 == $show_comment_count || 1 == $show_like_count ) {
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
			if ( 1 !== $show_comment_count && 1 !== $show_like_count && 1 == $show_share_with ) {
				echo '<div class="ssd-action-row">';
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
		} elseif ( 'tumblr' === $feed_type ) {
			$like_link                = $post_link;
						$comment_link = $post_link;
			if ( 1 == $show_comment_count || 1 == $show_like_count ) {
				echo '<div class="ssd-action-row">';
			}
			if ( 1 == $show_like_count && '' !== $like_link ) {
				?>
				<a target="_blank" title="<?php esc_html_e( 'Likes', 'social-stream-designer' ); ?>" href="<?php echo esc_url( $like_link ); ?>">
					<i class='fas fa-heart'></i>
					<?php if ( 1 == $show_like_count && '' !== $likes_count ) { ?>
						<span class='ssd-counts'><?php echo esc_attr( $likes_count ); ?></span>
						<?php
					}
					?>
				</a>
				<?php
			}
			if ( 1 == $show_comment_count && '' !== $comment_link ) {
				?>
				<a target="_blank" href="<?php echo esc_url( $comment_link ); ?>" title="<?php esc_html_e( 'Comments', 'social-stream-designer' ); ?>" >
					<i class='fas fa-comments'></i>
					<?php if ( 1 == $show_comment_count && '' !== $comments_count ) { ?>
						<span class='ssd-counts'><?php echo esc_attr( $comments_count ); ?></span>
					<?php } ?>
				</a>
				<?php
			}
			if ( 1 == $show_comment_count || 1 == $show_like_count ) {
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
			if ( 1 !== $show_comment_count && 1 !== $show_like_count && 1 == $show_share_with ) {
				echo '<div class="ssd-action-row">';
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
		} elseif ( 'dribbble' === $feed_type ) {
			if ( ( 1 == $show_comment_count && '' !== $comments_count ) ||
				( 1 == $show_like_count && '' !== $likes_count ) ||
				( 1 == $show_view_count && '' !== $plays_count ) ) {
				echo '<div class="ssd-action-row">';
			}
			if ( 1 == $show_comment_count && '' !== $comments_count ) {
				?>
					<a target="_blank" href="<?php echo esc_url( $post_video ); ?>" title="<?php esc_html_e( 'Comments', 'social-stream-designer' ); ?>" ><i class='fas fa-comments'></i><span class='ssd-counts'><?php echo esc_html( $comments_count ); ?></span></a>
														<?php
			}
			if ( 1 == $show_like_count && '' !== $likes_count ) {
				?>
					<a target="_blank" href="<?php echo esc_url( $post_video ); ?>" title="<?php esc_html_e( 'Likes', 'social-stream-designer' ); ?>" ><i class='far fa-heart'></i><span class='ssd-counts'><?php echo esc_html( $likes_count ); ?></span></a>
														<?php
			}
			if ( 1 == $show_view_count && '' !== $plays_count ) {
				?>
					<a target="_blank" href="<?php echo esc_url( $post_video ); ?>" title="<?php esc_html_e( 'Views', 'social-stream-designer' ); ?>" ><i class='far fa-eye'></i><span class='ssd-counts'><?php echo esc_html( $plays_count ); ?></span></a>
														<?php
			}
			if ( ( 1 == $show_comment_count && '' !== $comments_count ) || ( 1 == $show_like_count && '' !== $likes_count ) || ( 1 == $show_view_count && '' !== $plays_count ) || ( 1 == $show_dislike_count && '' !== $dislike_count ) ) {
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
			if ( 1 !== $show_comment_count && 1 !== $show_like_count && 1 !== $show_view_count && 1 !== $show_dislike_count && 1 == $show_share_with ) {
				echo '<div class="ssd-action-row">';
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
		} elseif ( 'WordPress' === $feed_type ) {
			if ( ( 1 == $show_comment_count && '' !== $comments_count ) ) {
				echo '<div class="ssd-action-row">';
			}
			if ( 1 == $show_comment_count && '' !== $comments_count ) {
				?>
				<a target="_blank" href="<?php echo esc_url( $post_video ); ?>" title="<?php esc_html_e( 'Comments', 'social-stream-designer' ); ?>" ><i class='fas fa-comments'></i><span class='ssd-counts'><?php echo esc_html( $comments_count ); ?></span></a>
				<?php
			}
			if ( ( 1 == $show_comment_count && '' !== $comments_count ) ) {
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
			if ( 1 !== $show_comment_count && 1 == $show_share_with ) {
				echo '<div class="ssd-action-row">';
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
		} elseif ( 'foursquare' === $feed_type ) {
			if ( 1 == $show_share_with ) {
				echo '<div class="ssd-action-row">';
				self::ssd_display_share_with_icon( $show_share_with, $post_link );
				echo '</div>';
			}
		}
	}
	/**
	 * Display loader on layout
	 *
	 * @return void
	 */
	public function ssd_loader_for_feeds() {
		?>
		<div style="display:none" class="ssd-loader-wrapper">
			<div class="ssd-loader-inner">
				<p><?php esc_html_e( 'This could take up to 2-5 minutes. We are fetching the posts from your feed. Please do not close this window until it\'s complete.', 'social-stream-designer' ); ?></p>
				<i class="fas fa-spinner fa-spin"></i>
			</div>
		</div>
		<?php
	}
	/**
	 * Display share urls in layout
	 *
	 * @param string $link url.
	 * @return void
	 */
	public static function ssd_share_link( $link ) {
		?>
		<div class="ssd-share-link-wrapper">
			<ul class="ssd-share-link">
				<li><a class="email" href="mailto:?&subject=dfsdf&body=<?php echo esc_url( $link ); ?>" target="blank" title="<?php echo esc_html( 'Email' ); ?>"><i class="far fa-envelope"></i></a></li>
				<li><a class="linkedin" href="https://www.linkedin.com/shareArticle?mini=true&url=<?php echo esc_url( $link ); ?>" target="blank" title="<?php echo esc_html( 'Linkedin' ); ?>"><i class="fab fa-linkedin-in"></i></a></li>
				<li><a class="pinterest" href="http://pinterest.com/pin/create/button/?url=<?php echo esc_url( $link ); ?>" target="blank" title="<?php echo esc_html( 'Pinterst' ); ?>"><i class="fab fa-pinterest-p"></i></a></li>
				<li><a class="facebook" href="http://www.facebook.com/sharer.php?u=<?php echo esc_url( $link ); ?>" target="blank" title="<?php echo esc_html( 'Facebook' ); ?>"><i class="fab fa-facebook-f"></i></a></li>
				<li><a class="twitter" href="http://twitter.com/share?url=<?php echo esc_url( $link ); ?>" target="blank" title="<?php echo esc_html( 'Twitter' ); ?>"><i class="fab fa-twitter"></i></a></li>
				<li><a class="tumblr" href="https://www.tumblr.com/widgets/share/tool?url=<?php echo esc_url( $link ); ?>" target="blank" title="<?php echo esc_html( 'Tumblr' ); ?>"><i class="fab fa-tumblr"></i></a></li>
			</ul>
			<span class="ssd-close-button"><i class="far fa-times-circle"></i></span>
		</div>
		<?php
	}
	/**
	 * Get height of justified grid
	 *
	 * @return void
	 */
	public function ssd_grid_height() {
		if ( isset( $_POST['nonce'] ) ) {
			$nonce = sanitize_text_field( wp_unslash( $_POST['nonce'] ) );
			if ( ! wp_verify_nonce( $nonce, 'ssd-function' ) ) {
				wp_send_json_error( array( 'ssd_function' => 'Nonce error' ) );
				die();
			}
		}
		$layout_id     = isset( $_POST['layout_id'] ) ? intval( $_POST['layout_id'] ) : '';
		$layout_object = new SSDLayoutsActions();
		$layout_object->init();
		$layout_object->id      = $layout_id;
		$layout_settings        = $layout_object->ssd_get_layout_detail();
		$social_stream_settings = array();
		if ( isset( $layout_settings->social_stream_settings ) && '' !== $layout_settings->social_stream_settings ) {
			$get_social_stream_settings = $layout_settings->social_stream_settings;
			$social_stream_settings     = unserialize( $get_social_stream_settings );
		}
		$ssd_justified_grid_height = isset( $social_stream_settings['ssd_justified_grid_height'] ) ? $social_stream_settings['ssd_justified_grid_height'] : '200';
		echo esc_attr( $ssd_justified_grid_height );
		exit();
	}

		/**
		 * Moderate feed from front side
		 *
		 * @return void
		 */
	public function ssd_approve_feed() {
		global $wpdb;
		if ( isset( $_POST['nonce'] ) ) {
			$nonce = sanitize_text_field( wp_unslash( $_POST['nonce'] ) );
			if ( ! wp_verify_nonce( $nonce, 'ssd-function' ) ) {
				wp_send_json_error( array( 'ssd_function' => 'Nonce error' ) );
				die();
			}
		}
		$unique_id = isset( $_POST['unique_id'] ) ? sanitize_text_field( $_POST['unique_id'] ) : 0;
		$status    = isset( $_POST['status'] ) ? sanitize_text_field( $_POST['status'] ) : '';
		if ( 'approve' == $status || 'unapprove' == $status ) {
			if ( 'approve' == $status ) {
				$f_status = 'yes';
			} elseif ( 'unapprove' == $status ) {
				$f_status = '';
			}
			$wpdb->update(
				$wpdb->prefix . 'ssd_feed_posts',
				array(
					'post_status' => $f_status,
				),
				array( 'unique_id' => $unique_id ),
				array(
					'%s',
				),
				array( '%s' )
			);
		}
		exit();
	}
	/**
	 * Display media based on type
	 *
	 * @param string $type_in media type.
	 * @param string $feed_type feed type.
	 * @param string $feed_type_stream feed type.
	 * @param string $link url.
	 * @param string $image image.
	 * @param string $video video.
	 * @param string $ssd_display_default_image default image.
	 * @param string $ssd_default_image_src default image source.
	 * @param string $ssd_design_layout default layout .
	 * @return void
	 */
	public static function ssd_media_type( $type_in, $feed_type, $feed_type_stream, $link, $image, $video, $ssd_display_default_image, $ssd_default_image_src, $ssd_design_layout, $ssd_title ) {
		global $wpdb;
		$ssd_display_default_image = (int) $ssd_display_default_image;
		$ssd_default_image         = '';
		$post_type_slug            = array();
		$args                      = array(
			'public'   => true,
			'_builtin' => false,
		);
		$post_types                = get_post_types( $args, 'objects' );
		if ( isset( $post_types ) ) {
			if ( is_array( $post_types ) && ! empty( $post_types ) ) {
				foreach ( $post_types as $post_type ) {
					$post_type_slug[] = $post_type->name;
				}
			}
		}
		$upload_file = '';
		if ( 1 == $ssd_display_default_image && '' !== $ssd_default_image_src ) {
			$ssd_default_image = $ssd_default_image_src;
		}
		if ( '' === $ssd_default_image_src && 'layout-4' === $ssd_design_layout ) {
			$ssd_default_image = SOCIALSTREAMDESIGNER_URL . '/images/No_available_image.png';
		}
		if ( 'image' === $type_in ) {
			if ( '' !== $image ) {
				$post_image_url = strtok( $image, '?' );
				$path_info      = pathinfo( $post_image_url );
				$file_name      = md5( $post_image_url );
				$file_extention = $path_info['extension'];
				if ( '' !== $file_extention ) {
					$file_extentions = parse_url( $file_extention );
					if ( is_array( $file_extentions ) ) {
						$file_extention = $file_extentions['path'];
					}
					$file_extention = '.' . $file_extention;
				} else {
					$file_extention = '.jpg';
				}
				$upload_file_path  = WP_CONTENT_DIR . '/uploads/social-stream/';
				$display_file_path = WP_CONTENT_URL . '/uploads/social-stream/';
				$upload_file       = $upload_file_path . $file_name . '_image' . $file_extention;
				$display_file      = $display_file_path . $file_name . '_image' . $file_extention;
			}
			if ( file_exists( $upload_file ) ) {
				?>
				<a target="_blank" href="<?php echo esc_url( $link ); ?>"><img alt="<?php echo esc_html( wp_strip_all_tags( $ssd_title ) ); ?>" src="<?php echo esc_url( $image ); ?>"></a>
													<?php
			} elseif ( '' !== $image ) {
				?>
				<a target="_blank" href="<?php echo esc_url( $link ); ?>"><img alt="<?php echo esc_html( wp_strip_all_tags( $ssd_title ) ); ?>" src="<?php echo esc_url( $image ); ?>"></a>
													<?php
			} elseif ( '' !== $ssd_default_image ) {
				?>
				<a target="_blank" href="<?php echo esc_url( $link ); ?>"><img src="<?php echo esc_html( wp_strip_all_tags( $ssd_title ) ); ?>"></a>
													<?php
			}
		} elseif ( 'video' === $type_in ) {
			if ( '' !== $video ) {
				?>
				<div class="ssd_video_play">
					<a target="_blank" href="<?php echo esc_url( $link ); ?>">
						<svg id="ssd_video_play" xmlns="http://www.w3.org/2000/svg" width="45" height="45" viewBox="0 0 45 45">
						<g id="Group_1" data-name="Group 1" transform="translate(-701 -412)">
						<path id="Fill-124" d="M-97.3-224.8a22.5,22.5,0,0,1-22.5-22.5,22.5,22.5,0,0,1,22.5-22.5,22.5,22.5,0,0,1,22.5,22.5,22.5,22.5,0,0,1-22.5,22.5Zm0-42.552A20.13,20.13,0,0,0-117.352-247.3,20.13,20.13,0,0,0-97.3-227.248,20.13,20.13,0,0,0-77.248-247.3,20.069,20.069,0,0,0-97.3-267.352Z" transform="translate(820.8 681.8)" fill="#fff"/>
						<path id="Fill-125" d="M-103-233.6v-24.7l21.2,12.4L-103-233.6Zm2.8-19.8v14.9l12.7-7.4-12.7-7.5Z" transform="translate(819.632 680.846)" fill="#fff"/>
						</g>
						</svg>					
					</a>
				</div>
				<?php
				if ( ( 'vimeo' === $feed_type ) ) {
					?>
					<a target="_blank" href="<?php echo esc_url( $link ); ?>"><img alt="<?php echo esc_html( wp_strip_all_tags( $ssd_title ) ); ?>" src="<?php echo esc_url( $image ); ?>"></a>
					<?php
				} elseif ( 'youtube' === $feed_type && ( 'user_feed' === $feed_type_stream || 'search' === $feed_type_stream || 'channel' === $feed_type_stream || 'playlists' === $feed_type_stream ) ) {
					?>
					<a target="_blank" href="<?php echo esc_url( $link ); ?>"><img alt="<?php echo esc_html( wp_strip_all_tags( $ssd_title ) ); ?>" src="<?php echo esc_url( $image ); ?>"></a>
					<?php
				} elseif ( 'tiktok' === $feed_type ) {
					?>
					<a target="_blank" href="<?php echo esc_url( $link ); ?>"><img alt="<?php echo esc_html( wp_strip_all_tags( $ssd_title ) ); ?>" src="<?php echo esc_url( $image ); ?>"></a>
					<?php
				} elseif ( 'flickr' === $feed_type ) {
					?>
					<a data-flickr-embed="true"  href="<?php echo esc_url( $video ); ?>"><img alt="<?php echo esc_url( $image ); ?>" src="<?php echo esc_url( $image ); ?>" width="1280" height="720"></a>
					<script async src="//embedr.flickr.com/assets/client-code.js" charset="utf-8"></script>
					<?php
				} else {
					?>
					<video controls><source src="<?php echo esc_url( $video ); ?>"></video>
					<?php
				}
			} else {
				if ( '' !== $image ) {
					?>
					<a target="_blank" href="<?php echo esc_url( $link ); ?>"><img alt="<?php echo esc_html( wp_strip_all_tags( $ssd_title ) ); ?>" src="<?php echo esc_url( $image ); ?>"></a>
														<?php
				} elseif ( '' !== $ssd_default_image ) {
					?>
					<a target="_blank" href="<?php echo esc_url( $link ); ?>"><img alt="<?php echo esc_html( wp_strip_all_tags( $ssd_title ) ); ?>" src="<?php echo esc_url( $ssd_default_image ); ?>"></a>
														<?php
				}
			}
		} elseif ( 'carousel' === $type_in || 'carousel_album' === $type_in ) {
			$images = explode( ' ,', $image );
			$videos = explode( ' ,', $video );
			?>
			<div class="ssd-carousel-media slickslider">
				<div class="slides">
					<?php
					$images_c = count( $images );
					for ( $i = 0; $i < $images_c; $i++ ) {
						if ( '' !== $images[ $i ] ) {
							?>
							<div><img alt="<?php echo esc_html( wp_strip_all_tags( $ssd_title ) ); ?>" src="<?php echo esc_url( $images[ $i ] ); ?>"></div>
							<?php
						}
					}
					$videos_c = count( $videos );
					for ( $j = 0; $j < $videos_c; $j++ ) {
						if ( '' !== $videos[ $j ] ) {
							?>
							<div>
								<video controls>
									<source src="<?php echo esc_url( $videos[ $j ] ); ?>">
								</video>
							</div>
							<?php
						}
					}
					?>
				</div>
			</div>
			<?php
		} elseif ( 'post' === $type_in || ( ! empty( $post_type_slug ) && in_array( $type_in, $post_type_slug, true ) ) ) {
			if ( '' !== $image ) {
				?>
				<a target="_blank" href="<?php echo esc_url( $link ); ?>"><img alt="<?php echo esc_html( wp_strip_all_tags( $ssd_title ) ); ?>" src="<?php echo esc_url( $image ); ?>"></a>
													<?php
			} elseif ( '' !== $ssd_default_image ) {
				?>
				<a target="_blank" href="<?php echo esc_url( $link ); ?>"><img alt="<?php echo esc_html( wp_strip_all_tags( $ssd_title ) ); ?>" src="<?php echo esc_url( $ssd_default_image ); ?>"></a>
													<?php
			}
		} elseif ( 'feed' === $type_in ) {
			if ( '' !== $ssd_default_image ) {
				?>
				<a target="_blank" href="<?php echo esc_url( $link ); ?>"><img alt="<?php echo esc_html( wp_strip_all_tags( $ssd_title ) ); ?>" src="<?php echo esc_url( $ssd_default_image ); ?>"></a>
				<?php
			}
		} else {
			if ( '' !== $ssd_default_image ) {
				?>
				<a target="_blank" href="<?php echo esc_url( $link ); ?>"><img alt="<?php echo esc_html( wp_strip_all_tags( $ssd_title ) ); ?>" src="<?php echo esc_url( $ssd_default_image ); ?>"></a>
				<?php
			}
		}
	}
	/**
	 * Display Share post link in layout
	 *
	 * @param int    $show_share_with if share display.
	 * @param string $post_link post link.
	 * @return void
	 */
	public static function ssd_display_share_with_icon( $show_share_with, $post_link ) {
		$show_share_with = (int) $show_share_with;
		if ( 1 == $show_share_with ) {
			?>
			<span class="ssd-share-button"><i class="fas fa-share-alt"></i></span>
			<?php
			self::ssd_share_link( $post_link );
		}
	}
	/**
	 * Display no feed available message
	 *
	 * @return void
	 */
	public function ssd_no_feeds_available_notice() {
		if ( isset( $_POST['nonce'] ) ) {
			$nonce = sanitize_text_field( wp_unslash( $_POST['nonce'] ) );
			if ( ! wp_verify_nonce( $nonce, 'ssd-function' ) ) {
				wp_send_json_error( array( 'ssd_function' => 'Nonce error' ) );
				die();
			}
		}
		if ( isset( $_GET['page'] ) && ( 'social-stream-designer-layouts' === $_GET['page'] || 'social-stream-designer-add-layouts' === $_GET['page'] ) ) {
			$all_feeds   = '';
			$feed_object = new SSDFeedsActions();
			$feed_object->init();
			$all_feeds = $feed_object->ssd_get_all_feeds();
			if ( '' == $all_feeds ) {
				?>
				<div class="notice notice-warning">
					<p>
					<?php esc_html_e( "You haven't created any feeds yet. Please create the feed before create the layout.", 'social-stream-designer' ); ?>
						<a href="<?php echo esc_url( admin_url( 'admin.php?page=social-stream-designer-social-feed' ) ); ?>" ><?php esc_html_e( 'Create New Feed', 'social-stream-designer' ); ?></a>
					</p>
				</div>
				<?php
			}
		}
	}
	/**
	 * Update drag and drop builder
	 *
	 * @return void
	 */
	public function ssd_update_drag_drop_builder() {
		if ( isset( $_POST['nonce'] ) ) {
			$nonce = sanitize_text_field( wp_unslash( $_POST['nonce'] ) );
			if ( ! wp_verify_nonce( $nonce, 'ssd-function' ) ) {
				wp_send_json_error( array( 'ssd_function' => 'Nonce error' ) );
				die();
			}
		}
		$layout = ( isset( $_POST['layout'] ) && '' !== $_POST['layout'] ) ? sanitize_text_field( wp_unslash( $_POST['layout'] ) ) : 'ssd_design_layout_1';
		if ( 'ssd_design_layout_1' === $layout ) {
			$ssd_social_order_e = 'media,title,content,author,count,';
		} elseif ( 'ssd_design_layout_2' === $layout ) {
			$ssd_social_order_e = 'media,title,content,count,';
		} elseif ( 'ssd_design_layout_3' === $layout ) {
			$ssd_social_order_e = 'media,title,content,count,';
		} else {
			$ssd_social_order_e = 'count,title,content,author,social-share,';
		}

		$ssd_social_order_e   = explode( ',', $ssd_social_order_e );
		$proper_ordered_array = $ssd_social_order_e;
		$proper_ordered_array = array_filter( $proper_ordered_array );
		$proper_ordered_array = array_unique( $proper_ordered_array );
		foreach ( $proper_ordered_array as $proper_ordered_val ) {
			$ssd_social_order[] = $proper_ordered_val;
		}
											$ssd_social_order_count = count( $ssd_social_order );
		for ( $i = 0; $i < $ssd_social_order_count; $i++ ) {
			if ( 'title' === $ssd_social_order[ $i ] ) {
				?>
				<li class="ui-sortable-handle" data-order="title">
					<h3><?php esc_html_e( '41 landing page optimization best practices', 'social-stream-designer' ); ?></h3>
				</li>
				<?php
			}
			if ( 'content' === $ssd_social_order[ $i ] ) {
				?>
				<li class="ui-sortable-handle" data-order="content">
					<p style="margin:0"><?php echo esc_html( 'At ornare ullamcorper potenti pulvinar wisi. Nibh faucibus nec duis elit eleifend accumsan libero sociis metus id feugiat. Quis interdum senectus. Luctus etiam consequat adipiscing lobortis nec. Massa wisi cras.' ); ?></p>
				</li>
				<?php
			}
			if ( 'social-share' === $ssd_social_order[ $i ] ) {
				?>
				<li class="ssd-social-share-sortable ui-sortable-handle" data-order="social-share">
					<div class="facebook-cover"><i class="fab fa-facebook-f"></i><?php esc_html_e( 'Facebook', 'social-stream-designer' ); ?></div>
				</li>
				<?php
			}
			if ( 'media' === $ssd_social_order[ $i ] ) {
				?>
				<li class="ssd-media-sortable ui-sortable-handle" data-order="media"><img src="<?php echo esc_url( SOCIALSTREAMDESIGNER_URL ) . '/images/layout-media.png'; ?>" alt="<?php esc_html_e( 'Sample Image', 'social-stream-designer' ); ?>"></li>
				<?php
			}
			if ( 'author' === $ssd_social_order[ $i ] ) {
				?>
				<li class="ssd-author-sortable ui-sortable-handle" data-order="author">
					<div class="ssd-author-detail">
						<div class='ssd-author-image'></div>
						<div class="ssd-author-name">
							<a href=''><?php esc_html_e( 'Solwin Infotech', 'social-stream-designer' ); ?></a>
							<a href=''>
							<?php
							esc_html_e( 'SolwinInfotech', 'social-stream-designer' );
							echo ' - ';
							esc_html_e( '3h ago', 'social-stream-designer' );
							?>
							</a>
						</div>
					</div>
				</li>
				<?php
			}
			if ( 'count' === $ssd_social_order[ $i ] ) {
				?>
				<li class="ui-sortable-handle" data-order="count">
					<div class="ssd-action-row">
						<a href=""><i class='fas fa-eye'></i><span class='ssd-counts'>17</span></a>
						<a href=""><i class='fas fa-comments'></i><span class='ssd-counts'>7</span></a>
						<a href=""><i class='fas fa-heart'></i><span class='ssd-counts'>9</span></a>
						<a href=""><i class='far fa-thumbs-up'></i><span class='ssd-counts'>5</span></a>
					</div>
				</li>
				<?php
			}
		}
		exit;
	}
	/**
	 * Get search result
	 *
	 * @param int $private_stream if stream display.
	 * @param int $desktop_stream if desktop stream.
	 * @param int $mobile_stream if mobile stream.
	 * @return boolean.
	 */
	public static function ssd_ispossible_display_data( $private_stream, $desktop_stream, $mobile_stream ) {
		$mobile = self::ssd_is_mobile_detector();
		if ( $mobile_stream && $mobile ) {
			return false;
		}
		if ( $desktop_stream && ! $mobile ) {
			return false;
		}
		if ( $private_stream && ! is_user_logged_in() ) {
			return false;
		}
		return true;
	}
	/**
	 * Check if mobile
	 *
	 * @return string
	 */
	public static function ssd_is_mobile_detector() {
		return preg_match(
			'/(android|webos|avantgo|iPhone|blackberry|iemobile|bolt|boost|cricket|docomo|fone|hiptop|mini|opera mini|kitkat|mobi|palm|phone|pie|tablet|up\.browser|up\.link|webos|wos|midp|j2me|avantg|novarra|palmos|palmsource|opwv|nokia|samsung|HTC|sony|lg|moto)/i',
			( ! empty( $_SERVER['HTTP_USER_AGENT'] ) ? sanitize_text_field( wp_unslash( $_SERVER['HTTP_USER_AGENT'] ) ) : 'unknown' )
		);
	}
	/**
	 * Get data from url using curl or wp_remote_get
	 *
	 * @param string $url url.
	 * @return json $get_insta_user_feed feed data.
	 */
	public static function ssd_get_data_from_remote_url( $url ) {
		$get_insta_user_feed = '';
		if ( '' !== $url ) {
				$args     = array(
					'timeout' => 120,
				);
				$response = wp_remote_get( $url, $args );
				if ( is_wp_error( $response ) ) {
						return false;
				}
				$get_insta_user_feed = wp_remote_retrieve_body( $response );
		}
		return $get_insta_user_feed;
	}
	/**
	 * Get image from url and store in local
	 *
	 * @param string $upload_file upload file url.
	 * @param string $post_image_url image url.
	 */
	public static function ssd_put_media_file_in_local( $upload_file, $post_image_url ) {
		global $wp_filesystem;
		/* get image data from url. */
		$get_insta_user_feed = '';
		if ( '' !== $post_image_url ) {
				$args     = array(
					'timeout' => 120,
				);
				$response = wp_remote_get( $post_image_url, $args );
				if ( is_wp_error( $response ) ) {
						return false;
				}
				$get_insta_user_feed = wp_remote_retrieve_body( $response );
		}
		$image_data = $get_insta_user_feed;
		if ( empty( $wp_filesystem ) ) {
			require_once ABSPATH . '/wp-admin/includes/file.php';
			WP_Filesystem();
		}
		/* Save image on local system. */
		$url   = wp_nonce_url( admin_url( 'admin.php?page=social-stream-designer-social-feed' ), 'social-stream-designer' );
		$creds = request_filesystem_credentials( $url, '', true, false, null );
		if ( false == $creds ) {
			esc_html_e( 'Credentials are required to save the file.', 'social-stream-designer' );
			exit();
		}
		if ( ! WP_Filesystem( $creds ) ) {
			request_filesystem_credentials( $url, '', true, false, null );
		}
		$wp_filesystem->put_contents( $upload_file, $image_data, FS_CHMOD_FILE );
	}
	
	/**
	 * Check plugin last error
	 *
	 * @return array $error
	 */
	public static function ssd_get_last_error() {
		$error = wp_get_plugin_error( 'social-stream-designer/social-stream-designer.php' );
		return $error;
	}

	/**
	 * Get all tweets launges
	 */
	public static function ssd_tweets_language() {
		$language = array( 'am' => 'Amharic','ar' => 'Arabic','bg' => 'Bulgarian','bn' => 'Bengali','bo' => 'Tibetan','ch' => 'Cherokee','da' => 'Danish','de' => 'German','dv' => 'Maldivian','el' => 'Greek','en' => 'English','es' => 'Spanish','fa' => 'Persian','fi' => 'Finnish','fr' => 'French','gu' => 'Gujarati','iw' => 'Hebrew','hi' => 'Hindi','hu' => 'Hungarian','hy' => 'Armenian','in' => 'Indonesian','is' => 'Icelandic','it' => 'Italian','iu' => 'Inuktitut','ja' => 'Japanese','ka' => 'Georgian','km' => 'Khmer','kn' => 'Kannada','ko' => 'Korean','lo' => 'Lao','lt' => 'Lithuanian','ml' => 'Malayalam','my' => 'Myanmar','ne' => 'Nepali','nl' => 'Dutch','no' => 'Norwegian','or' => 'Oriya','pa' => 'Panjabi','pl' => 'Polish','pt' => 'Portuguese','ru' => 'Russian','si' => 'Sinhala','sv' => 'Swedish','ta' => 'Tamil','te' => 'Telugu','th' => 'Thai','tl' => 'Tagalog','tr' => 'Turkish','ur' => 'Urdu','vi' => 'Vietnamese','zh' => 'Chinese');
		return $language;
	}
}
new Social_Stream_Main();
